@@ -7,6 +7,5 @@ package audio1
 type PortInfo struct {
 	Name        string
 	Description string
-	Priority    uint32
-	Available   int // 0: Unknown, 1: No, 2: Yes
+	Available   byte // 0: Unknown, 1: No, 2: Yes
 }
